summaryrefslogtreecommitdiffstats
path: root/libkdegames/kgame/kgamemessage.h
diff options
context:
space:
mode:
Diffstat (limited to 'libkdegames/kgame/kgamemessage.h')
-rw-r--r--libkdegames/kgame/kgamemessage.h18
1 files changed, 9 insertions, 9 deletions
diff --git a/libkdegames/kgame/kgamemessage.h b/libkdegames/kgame/kgamemessage.h
index 4394b4fa..d671a948 100644
--- a/libkdegames/kgame/kgamemessage.h
+++ b/libkdegames/kgame/kgamemessage.h
@@ -23,7 +23,7 @@
#ifndef __KGAMEMSG_H_
#define __KGAMEMSG_H_
-#include <qdatastream.h>
+#include <tqdatastream.h>
#include <kdemacros.h>
class KDE_EXPORT KGameMessage
@@ -85,34 +85,34 @@ class KDE_EXPORT KGameMessage
* (message length and magic cookie). If you don't need them remove them
* with @ref dropExternalHeader
*/
- static void createHeader(QDataStream &msg, Q_UINT32 sender, Q_UINT32 receiver, int msgid);
+ static void createHeader(TQDataStream &msg, Q_UINT32 sender, Q_UINT32 receiver, int msgid);
/**
* Retrieves the information like cookie,sender,receiver,... from a message header
*
* Note that it could be necessary to call @ref dropExternalHeader first
*/
- static void extractHeader(QDataStream &msg,Q_UINT32 &sender, Q_UINT32 &receiver, int &msgid);
+ static void extractHeader(TQDataStream &msg,Q_UINT32 &sender, Q_UINT32 &receiver, int &msgid);
/**
* Creates a property header given the property id
*/
- static void createPropertyHeader(QDataStream &msg, int id);
+ static void createPropertyHeader(TQDataStream &msg, int id);
/**
* Retrieves the property id from a property message header
*/
- static void extractPropertyHeader(QDataStream &msg, int &id);
+ static void extractPropertyHeader(TQDataStream &msg, int &id);
/**
* Creates a property header given the property id
*/
- static void createPropertyCommand(QDataStream &msg, int cmdid, int pid, int cmd);
+ static void createPropertyCommand(TQDataStream &msg, int cmdid, int pid, int cmd);
/**
* Retrieves the property id from a property message header
*/
- static void extractPropertyCommand(QDataStream &msg, int &pid, int &cmd);
+ static void extractPropertyCommand(TQDataStream &msg, int &pid, int &cmd);
/**
* @return Version of the network library
@@ -124,10 +124,10 @@ class KDE_EXPORT KGameMessage
* suitable string for it. This string can't be used to identify a message
* (as it is i18n'ed) but it can make debugging more easy. See also @ref
* KGameDebugDialog.
* @return Either a i18n'ed string (the name of the id) or QString::null if
* the msgid is unknown
**/
- static QString messageId2Text(int msgid);
+ static TQString messageId2Text(int msgid);
/**
@@ -124,10 +124,10 @@ class KDE_EXPORT KGameMessage
* (as it is i18n'ed) but it can make debugging more easy. See also @ref
* KGameDebugDialog.
- * @return Either a i18n'ed string (the name of the id) or QString::null if
+ * @return Either a i18n'ed string (the name of the id) or TQString::null if
* the msgid is unknown
**/